@@ -3,6 +3,10 @@
 #include <structmember.h>
 
 #include <plutobook.h>
+#if defined(_WIN32)
+#include <windows.h>
+#include <string.h>
+#endif
 
 #ifndef PLUTOPRINT_VERSION_MAJOR
 #define PLUTOPRINT_VERSION_MAJOR 0
@@ -1733,5 +1737,20 @@ PyMODINIT_FUNC PyInit__plutoprint(void)
     PyModule_AddIntConstant(module, "PLUTOBOOK_VERSION_MAJOR", PLUTOBOOK_VERSION_MAJOR);
     PyModule_AddStringConstant(module, "PLUTOBOOK_VERSION_STRING", PLUTOBOOK_VERSION_STRING);
 
+#ifdef _WIN32
+    HMODULE handle = NULL;
+    GetModuleHandleExA(GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS | GET_MODULE_HANDLE_EX_FLAG_UNCHANGED_REFCOUNT, (LPCSTR)&PyInit__plutoprint, &handle);
+
+    char path[MAX_PATH];
+    GetModuleFileNameA(handle, path, MAX_PATH);
+
+    char* slash = strrchr(path, '\\');
+    if(slash) {
+        *slash = '\0';
+    }
+
+    plutobook_set_fontconfig_path(strcat(path, "\\fontconfig"));
+#endif
+
     return module;
 }
